function varargout = augmented_hyperplane( varargin)

	vectors = {};
	for i=1:nargin,
		vectors{end+1} = varargin{i};
	end

	w = ( vectors{1} - vectors{2})';
	ww = -( vectors{1}'*vectors{1} - vectors{2}'*vectors{2}) / 2;
	fprintf( '\nEquation of the hyperplane is ');
	for i=1:length(w),
		if i==1
			fprintf( '%.3f * x%d', w(i), i);
		else
			if w(i)>=0
				fprintf( ' + %.3f * x%d', abs(w(i)), i);
			else
				fprintf( ' - %.3f * x%d', abs(w(i)), i);
			end
		end
	end
	if ww<0
		fprintf( ' - %.3f = 0\n', abs(c));
	else
		fprintf( ' + %.3f = 0\n', ww);
	end
	
	d={};
	for i=1:nargin
		d{end+1} = w * vectors{i} + ww;
	end;
	if d{1} > 0 
		positive_one = true;
	end;
		
	for i=3:nargin,
		if d{i} > 0
			if positive_one
				fprintf('Pattern #%d computes d(x)=%.3f [d(x)>0] and belongs to the area of reference pattern 1.\n',i,d{i});
			else
				fprintf('Pattern #%d computes d(x)=%.3f [d(x)>0] and belongs to the area of reference pattern 2.\n',i,d{i});
			end
		end
		if d{i} < 0
			if positive_one
				fprintf('Pattern #%d computes d(x)=%.3f [d(x)<0] and belongs to the area of reference pattern 2.\n',i,d{i});
			else
				fprintf('Pattern #%d computes d(x)=%.3f [d(x)<0] and belongs to the area of reference pattern 1.\n',i,d{i});
			end
		end
	end;

	dimensions = length( vectors{1});
	lims = limits(cell2mat(vectors));
	lims(1) = lims(1)-2;
	lims(2) = lims(2)+2;

	x0=[0 -ww/w(2) 1];
	y0=[-ww/w(1) 0 1];
	z0=[0 0 0];
	normal = cross(x0-y0,x0-z0);
	plane_params = [ normal dot(normal,x0)];
	X = lims(1):.1:lims(2);
	[X,Y] = meshgrid( X );
	Z = -(plane_params(4) + plane_params(1)*X + plane_params(2)*Y) / plane_params(3);
	figure;
	mesh( X, Y, Z, 'FaceColor', 'none', 'EdgeColor', [.5 .5 .5], 'FaceAlpha', 0.5); 
	set(gco,'FaceAlpha',0.5);
	hold on;
	for i=1:nargin
		v = vectors{i};
		v = [ v; 1];
		plot3( v(1), v(2), v(3), 'o', 'LineWidth',2,'MarkerSize',8);
		text( v(1)-.25, v(2)-.25, v(3)+.25, sprintf('x%d',i), 'FontSize', 14);
	end;
	%plot3( x0(1),x0(2),x0(3), 'or', 'LineWidth',2,'MarkerSize',8);
	%plot3( y0(1),y0(2),y0(3), 'or', 'LineWidth',2,'MarkerSize',8);
	%line( [x0(1),y0(1)], [x0(2),y0(2)], [x0(3),y0(3)], 'Color', 'red', 'LineWidth',2);
		X1 = lims(1):.1:lims(2);
		X2 = -( ww + w(1) * X1 ) / w(2);
		plot3( X1,  X2, ones(size(X2)), 'r', 'LineWidth',2);

	plot3( z0(1),z0(2),z0(3), 'or', 'LineWidth',2,'MarkerSize',8);
	Z = -(-1 + 0*X + 0*Y) / 1;
	mesh( X, Y, Z, 'FaceColor', 'none', 'EdgeColor', 'blue', 'FaceAlpha', 0.5); 
	set(gco,'FaceAlpha',0.5)
	axis equal; rotate3d on;
	xlabel('x_1');
	ylabel('x_2');
	zlabel('x_3');
	axis([-2 4, -2 5, -3 3]);
	hold off;

	
	return
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	
	if dimensions == 2,
		figure;
		hold on;
		for i=1:nargin
			plot( vectors{i}(1), vectors{i}(2), 'o');
			text( vectors{i}(1)-.2, vectors{i}(2)-.2, sprintf('x%d',i));
		end;
		X1 = lims(1):.1:lims(2);
		X2 = -( ww + w(1) * X1 ) / w(2);
		plot( X1,  X2);
		xlabel('x1');
		ylabel('x2');
		hold off;
		axis equal;
		grid on;
		zoom on;
	end
	if dimensions == 3,
		figure;
		hold on;
		for i=1:nargin
			plot3( vectors{i}(1), vectors{i}(2), vectors{i}(3), 'o');
			text( vectors{i}(1)-.2, vectors{i}(2)-.2, vectors{i}(3)-.2, sprintf('x%d',i));
		end;
		X = lims(1):.1:lims(2);
		[X,Y] = meshgrid( X );
		Z = -(ww + w(1)*X + w(2)*Y) / w(3);
		surf( X, Y, Z); colormap gray; shading interp;
		axis equal;
		grid on;
		xlabel('x1');
		ylabel('x2');
		zlabel('x3');
		rotate3d on;
	end